Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2008)

Unified Diff: net/url_request/url_request_unittest.cc

Issue 2026213002: Refactor CertificateReportSender (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/url_request/report_sender_unittest.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/url_request/url_request_unittest.cc
diff --git a/net/url_request/url_request_unittest.cc b/net/url_request/url_request_unittest.cc
index 0fce7f0ca3762f56fd719892e0daa2039daad276..e2fcad27fe42439057f28e850267ace746dadf47 100644
--- a/net/url_request/url_request_unittest.cc
+++ b/net/url_request/url_request_unittest.cc
@@ -659,10 +659,10 @@ class TestURLRequestContextWithProxy : public TestURLRequestContext {
~TestURLRequestContextWithProxy() override {}
};
// A mock ReportSender that just remembers the latest report
// URI and report to be sent.
class MockCertificateReportSender
- : public TransportSecurityState::ReportSender {
+ : public TransportSecurityState::ReportSenderInterface {
public:
MockCertificateReportSender() {}
~MockCertificateReportSender() override {}
@@ -659,10 +659,10 @@ class TestURLRequestContextWithProxy : public TestURLRequestContext {
~TestURLRequestContextWithProxy() override {}
};
-// A mock ReportSender that just remembers the latest report
+// A mock ReportSenderInterface that just remembers the latest report
// URI and report to be sent.
class MockCertificateReportSender
« no previous file with comments | « net/url_request/report_sender_unittest.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698